#define MICROPY_HW_BOARD_NAME               "FeatherS3"
#define MICROPY_HW_MCU_NAME                 "ESP32-S3"
#define MICROPY_PY_NETWORK_HOSTNAME_DEFAULT "FeatherS3"

#define MICROPY_HW_I2C0_SCL                 (9)
#define MICROPY_HW_I2C0_SDA                 (8)

#define MICROPY_HW_I2C1_SCL                 (15)
#define MICROPY_HW_I2C1_SDA                 (16)

#define MICROPY_HW_SPI1_MOSI                (35)
#define MICROPY_HW_SPI1_MISO                (37)
#define MICROPY_HW_SPI1_SCK                 (36)

#define MICROPY_HW_USB_VID 0x303A
#define MICROPY_HW_USB_PID 0x80D7
#define MICROPY_HW_USB_MANUFACTURER_STRING "Unexpected Maker"
#define MICROPY_HW_USB_PRODUCT_FS_STRING "FeatherS3"
